==> haskell-hw-hspec-hedgehog-0.1.1.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-16oLZztrQwOFKzSUcnO5JL
key:                  hw-hspec-hedgehog-0.1.1.1-16oLZztrQwOFKzSUcnO5JL
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  32138afb609016f9616f7084f09eaf8b
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-16oLZztrQwOFKzSUcnO5JL
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy base-4.16.4.0
    call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    hedgehog-1.2-I9IyB1h7sDn9Uxr3yTYmGm
    hspec-2.10.9-KtC7cFpktzjAEMyfIDiE4H transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-hspec-hedgehog-0.1.1.1-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-7psjzW7kuwOKOnBUfpd0Sx
key:                  hw-hspec-hedgehog-0.1.1.1-7psjzW7kuwOKOnBUfpd0Sx
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  dab9dc11e5f42a92a4f011cde58a1e6a
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-7psjzW7kuwOKOnBUfpd0Sx
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy base-4.16.4.0
    call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    hedgehog-1.2-2JjuPTBJYzR4k51ORigDUC
    hspec-2.10.9-KGzv9RVsU87FxL7qCXeFtE transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
